@@ -7,7 +7,7 @@ namespace Icinga\Module\Icingadb\Model;
 use Icinga\Module\Icingadb\Model\Behavior\ReRoute;
 use ipl\Orm\Behavior\Binary;
 use ipl\Orm\Behaviors;
-use Icinga\Module\Icingadb\Common\Model;
+use ipl\Orm\Model;
 use ipl\Orm\Relations;
 
 /**
@@ -71,7 +71,9 @@ class Hostgroup extends Model
     public function createBehaviors(Behaviors $behaviors)
     {
         $behaviors->add(new ReRoute([
-            'servicegroup'  => 'service.servicegroup'
+            'servicegroup'  => 'service.servicegroup',
+            'parent'        => 'host.from.to',
+            'child'         => 'host.to.from'
         ]));
 
         $behaviors->add(new Binary([
